<!-- LTeX: enabled=false -->
# Experiment

::: prob_conf_mat.experiment.Experiment
    options:
        members:
            - num_classes
            - num_predictions
            - num_experiments
            - confusion_matrix
            - prevalence_prior
            - confusion_prior

## Sampling

::: prob_conf_mat.experiment.Experiment.sample
    options:
        heading_level: 3

::: prob_conf_mat.experiment.Experiment.sample_metrics
    options:
        heading_level: 3

::: prob_conf_mat.experiment.ExperimentResult
    options:
        heading_level: 2
